@@ -10,10 +10,10 @@
 #' that begin with the specified prefix
 #' @param delimiter (character) string used to group keys. Read the AWS
 #' doc for more detail.
-#' @param ... curl args passed on to \code{\link[httr]{GET}}
+#' @param ... curl args passed on to [crul::HttpClient()]
 #'
-#' @details This is an alternative to using \code{\link{lsat_scenes}}. This
-#' function uses the AWS S3 API, while \code{\link{lsat_scenes}} downloads
+#' @details This is an alternative to using [lsat_scenes()]. This
+#' function uses the AWS S3 API, while [lsat_scenes()] downloads
 #' the up to date compressed csv file.
 #'
 #' @examples \dontrun{
@@ -24,16 +24,16 @@
 #' lsat_list(marker = res$Key[10], max = 10)
 #'
 #' # curl options
-#' library("httr")
-#' lsat_list(max = 3, config = verbose())
+#' lsat_list(max = 3, verbose = TRUE)
 #' }
 lsat_list <- function(max = NULL, marker = NULL, prefix = NULL,
                       delimiter = NULL, ...) {
   args <- tc(list(`max-keys` = max, marker = marker, prefix = prefix,
                   delimiter = delimiter))
-  tmp <- parsxml(lsat_GET(lsat_base(), query = args, ...))
+  tmp <- lsat_GET(lsat_base(), args, ...)
+  dat <- parsxml(tmp$parse("UTF-8"))
   df <- data.table::setDF(
-    data.table::rbindlist(tmp, fill = TRUE, use.names = TRUE)
+    data.table::rbindlist(dat, fill = TRUE, use.names = TRUE)
   )
   tibble::as_data_frame(df)
 }
